@@ -14,6 +14,7 @@
 
 #include <config.h>
 #include <unistd.h>
+#include <sys/stat.h>
 #include "calendar.h"
 #include "alarm.h"
 #include "timeutil.h"
@@ -22,14 +23,19 @@
 /* Our day range */
 time_t calendar_day_begin, calendar_day_end;
 
+static void calendar_init_alarms (Calendar *cal);
+
 Calendar *
 calendar_new (char *title)
 {
 	Calendar *cal;
 
 	cal = g_new0 (Calendar, 1);
+
 	cal->title = g_strdup (title);
 
+	calendar_init_alarms (cal);
+	
 	return cal;
 }
 
@@ -46,7 +52,7 @@ try_add (iCalObject *ico, CalendarAlarm *alarm, time_t start, time_t end)
 }
 
 static int
-add_alarm (iCalObject *obj, time_t start, time_t end, void *closure)
+add_object_alarms (iCalObject *obj, time_t start, time_t end, void *closure)
 {
 	if (obj->aalarm.enabled)
 		try_add (obj, &obj->aalarm, start, end);
@@ -77,7 +83,7 @@ ical_object_try_alarms (iCalObject *obj)
 	if (max_o == -1)
 		return;
 	
-	ical_object_generate_events (obj, calendar_day_begin, calendar_day_end + max_o, add_alarm, obj);
+	ical_object_generate_events (obj, calendar_day_begin, calendar_day_end + max_o, add_object_alarms, obj);
 }
 
 void
@@ -274,12 +280,22 @@ calendar_load_from_vobject (Calendar *cal, VObject *vcal)
 	}
 }
 
+static void
+calendar_set_day (void)
+{
+	time_t calendar_today;
+	
+	calendar_today     = time (NULL);
+	calendar_day_begin = time_day_begin (calendar_today);
+	calendar_day_end   = time_day_end (calendar_today);
+}
+
 /* Loads a calendar from a file */
 char *
 calendar_load (Calendar *cal, char *fname)
 {
 	VObject *vcal;
-	time_t calendar_today;
+	struct stat s;
 	
 	if (cal->filename){
 		g_warning ("Calendar load called again\n");
@@ -291,9 +307,10 @@ calendar_load (Calendar *cal, char *fname)
 	if (!vcal)
 		return "Could not load the calendar";
 
-	calendar_today     = time (NULL);
-	calendar_day_begin = time_day_begin (calendar_today);
-	calendar_day_end   = time_day_end (calendar_today);
+	stat (fname, &s);
+	cal->file_time = s.st_mtime;
+
+	calendar_set_day ();
 		
 	calendar_load_from_vobject (cal, vcal);
 	cleanVObject (vcal);
@@ -307,6 +324,7 @@ calendar_save (Calendar *cal, char *fname)
 	VObject *vcal;
 	GList   *l;
 	time_t  now = time (NULL);
+	struct  stat s;
 	
 	if (fname == NULL)
 		fname = cal->filename;
@@ -348,6 +366,9 @@ calendar_save (Calendar *cal, char *fname)
 		g_free (backup_name);
 	}
 	writeVObjectToFile (fname, vcal);
+
+	stat (fname, &s);
+	cal->file_time = s.st_mtime;
 	
 	cleanVObject (vcal);
 	cleanStrTbl ();
@@ -409,3 +430,28 @@ calendar_object_changed (Calendar *cal, iCalObject *obj, int flags)
 		;
 	ical_object_try_alarms (obj);
 }
+
+static void
+calendar_day_change (time_t time, CalendarAlarm *which, void *closure)
+{
+	GList *events;
+	Calendar *cal = closure;
+	
+	calendar_set_day ();
+
+	for (events = cal->events; events; events = events->next){
+		iCalObject *obj = events->data;
+
+		ical_object_try_alarms (obj);
+	}
+}
+
+static void
+calendar_init_alarms (Calendar *cal)
+{
+	CalendarAlarm day_change_alarm;
+
+	day_change_alarm.trigger = calendar_day_end;
+	alarm_add (&day_change_alarm, calendar_day_change, cal);
+}
+
