@@ -276,7 +276,7 @@ gnomecard_create_address_page(Card *crd, GnomeCardEditor *ce,
     ce->curaddr = 1;
     for (i = 0; i < 6; i++) {
 	ce->addrtype[i]=gtk_radio_button_new_with_label(addrtypegroup,
-							addr_type_name[i]);
+							_(addr_type_name[i]));
 	addrtypegroup = gtk_radio_button_group(GTK_RADIO_BUTTON(ce->addrtype[i]));
 	gtk_object_set_user_data(GTK_OBJECT(ce->addrtype[i]),
 				 (gpointer) (1 << i));
