@@ -1,3 +1,24 @@
+/* GnomeCard - a graphical contact manager.
+ *
+ * gnomecard.c: This file is part of GnomeCard.
+ * 
+ * Copyright (C) 1999 The Free Software Foundation
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 #include <gnome.h>
 #include <libgnorba/gnorba.h>
@@ -33,7 +54,6 @@
 #define GEO 1
 #define ORG 2
 #define EXP 3
-#define SEC 4
 
 GnomeApp *gnomecard_window;
 
@@ -621,11 +641,9 @@ void gnomecard_init(void)
 	gnome_app_set_statusbar(GNOME_APP(gnomecard_window),
 				GTK_WIDGET(appbar));
 
-#if 0
 	gtk_window_set_wmclass(GTK_WINDOW(gnomecard_window), "gnomecard",
 			       "gnomecard");
 	gtk_window_set_policy(GTK_WINDOW(gnomecard_window), TRUE, TRUE, TRUE);
-#endif
 			      
 	gtk_signal_connect(GTK_OBJECT(gnomecard_window), "delete_event",
 			   GTK_SIGNAL_FUNC(gnomecard_delete), NULL);
