@@ -249,7 +249,7 @@ gnomecard_create_phone_page(Card *crd, GnomeCardEditor *ce,
     ce->curphone = 1;
     for (i = 0; i < 6; i++) {
 	ce->phonetype[i]=gtk_radio_button_new_with_label(phonetypegroup,
-							 phone_type_name[i]);
+							 _(phone_type_name[i]));
 	phonetypegroup = gtk_radio_button_group(GTK_RADIO_BUTTON(ce->phonetype[i]));
 	gtk_object_set_user_data(GTK_OBJECT(ce->phonetype[i]),
 				 (gpointer) (1 << i));
